@@ -10,10 +10,10 @@
 
 #include <KCompositeJob>
 
+#include <QList>
 #include <QMap>
 #include <QPointer>
 #include <QString>
-#include <QVector>
 
 #include "akregator_export.h"
 
@@ -27,20 +27,20 @@ class TreeNode;
 struct ArticleId {
     QString feedUrl;
     QString guid;
-    Q_REQUIRED_RESULT bool operator<(const ArticleId &other) const
+    [[nodiscard]] bool operator<(const ArticleId &other) const
     {
         return feedUrl < other.feedUrl || (feedUrl == other.feedUrl && guid < other.guid);
     }
 };
 
-using ArticleIdList = QVector<Akregator::ArticleId>;
+using ArticleIdList = QList<Akregator::ArticleId>;
 
 class AKREGATOR_EXPORT CompositeJob : public KCompositeJob
 {
     Q_OBJECT
 public:
     explicit CompositeJob(QObject *parent = nullptr);
-    Q_REQUIRED_RESULT bool addSubjob(KJob *job) override;
+    [[nodiscard]] bool addSubjob(KJob *job) override;
     void start() override;
 };
 
@@ -90,7 +90,7 @@ class AKREGATOR_EXPORT ArticleListJob : public KJob
 public:
     explicit ArticleListJob(TreeNode *parent = nullptr);
 
-    QVector<Article> articles() const;
+    QList<Article> articles() const;
     TreeNode *node() const;
 
     void start() override;
@@ -102,6 +102,6 @@ private Q_SLOTS:
 
 private:
     const QPointer<TreeNode> m_node;
-    QVector<Article> m_articles;
+    QList<Article> m_articles;
 };
 } // namespace akregator
