@@ -206,7 +206,7 @@ MainWidget::MainWidget(Part *part, QWidget *parent, ActionManagerImpl *actionMan
 
     connect(m_articleListView, &ArticleListView::signalMouseButtonPressed, this, &MainWidget::slotMouseButtonPressed);
 
-    m_articleViewer = new ArticleViewerWidget(Settings::grantleeDirectory(), m_actionManager->actionCollection(), m_articleSplitter);
+    m_articleViewer = new ArticleViewerWidget(m_actionManager->actionCollection(), m_articleSplitter);
     m_articleListView->setFocusProxy(m_articleViewer);
     setFocusProxy(m_articleViewer);
 
@@ -863,7 +863,7 @@ void MainWidget::slotFetchingStarted()
 {
     m_mainFrame->slotSetState(Frame::Started);
     m_actionManager->action(QStringLiteral("feed_stop"))->setEnabled(true);
-    m_mainFrame->slotSetStatusText(i18n("Fetching Feeds..."));
+    m_mainFrame->slotSetStatusText(i18n("Fetching Feeds…"));
 }
 
 void MainWidget::slotFetchingStopped()
