@@ -127,15 +127,18 @@ void MainWindow::slotToggleMenubar(bool dontShowWarning)
             menuBar()->hide();
         }
         Settings::setShowMenuBar(mShowMenuBarAction->isChecked());
+        Settings::self()->save();
     }
 }
 
 void MainWindow::updateHamburgerMenu()
 {
+#if 0	
     delete mHamburgerMenu->menu();
     auto menu = new QMenu(this);
     menu->addAction(actionCollection()->action(KStandardAction::name(KStandardAction::Quit)));
     mHamburgerMenu->setMenu(menu);
+#endif
 }
 
 bool MainWindow::loadPart()
