@@ -8,6 +8,8 @@
 
 #include "searchbar.h"
 #include "akregatorconfig.h"
+#include "statussearchbuttons.h"
+#include "statussearchline.h"
 
 #include "article.h"
 #include <TextUtils/ConvertText>
@@ -28,6 +30,7 @@ using namespace Akregator::Filters;
 SearchBar::SearchBar(QWidget *parent)
     : QWidget(parent)
     , m_searchLine(new StatusSearchLine(this))
+    , m_statusSearchButtons(new StatusSearchButtons(this))
 {
     m_delay = 400;
     auto layout = new QHBoxLayout(this);
@@ -37,12 +40,13 @@ SearchBar::SearchBar(QWidget *parent)
     setSizePolicy(QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed));
 
     m_searchLine->setClearButtonEnabled(true);
-    m_searchLine->setPlaceholderText(i18n("Search articles..."));
+    m_searchLine->setPlaceholderText(i18nc("@info:placeholder", "Search articles…"));
     layout->addWidget(m_searchLine);
+    layout->addWidget(m_statusSearchButtons);
 
     connect(m_searchLine, &KLineEdit::textChanged, this, &SearchBar::slotSearchStringChanged);
     connect(m_searchLine, &StatusSearchLine::forceLostFocus, this, &SearchBar::forceLostFocus);
-    connect(m_searchLine, &StatusSearchLine::statusChanged, this, &SearchBar::slotStatusChanged);
+    connect(m_statusSearchButtons, &StatusSearchButtons::statusChanged, this, &SearchBar::slotStatusChanged);
 
     connect(&m_timer, &QTimer::timeout, this, &SearchBar::slotActivateSearch);
     m_timer.setSingleShot(true);
@@ -55,9 +59,9 @@ QString SearchBar::text() const
     return m_searchText;
 }
 
-StatusSearchLine::Status SearchBar::status() const
+StatusSearchButtons::Status SearchBar::status() const
 {
-    return m_searchLine->status();
+    return m_statusSearchButtons->status();
 }
 
 void SearchBar::setDelay(int ms)
@@ -77,9 +81,10 @@ void SearchBar::setFocusSearchLine()
 
 void SearchBar::slotClearSearch()
 {
-    if (status() != Akregator::StatusSearchLine::AllArticles || !m_searchLine->text().trimmed().isEmpty()) {
+    if (status() != Akregator::StatusSearchButtons::AllArticles || !m_searchLine->text().trimmed().isEmpty()) {
         m_searchLine->clear();
-        m_searchLine->setStatus(Akregator::StatusSearchLine::AllArticles);
+        m_statusSearchButtons->setStatus(Akregator::StatusSearchButtons::AllArticles);
+        m_statusSearchButtons->setStatus(Akregator::StatusSearchButtons::AllArticles);
         m_timer.stop();
         slotStopActiveSearch();
     }
@@ -87,7 +92,8 @@ void SearchBar::slotClearSearch()
 
 void SearchBar::slotSetStatus(int status)
 {
-    m_searchLine->setStatus(static_cast<Akregator::StatusSearchLine::Status>(status));
+    m_statusSearchButtons->setStatus(static_cast<Akregator::StatusSearchButtons::Status>(status));
+    m_statusSearchButtons->setStatus(static_cast<Akregator::StatusSearchButtons::Status>(status));
     triggerTimer();
 }
 
@@ -97,7 +103,7 @@ void SearchBar::slotSetText(const QString &text)
     triggerTimer();
 }
 
-void SearchBar::slotStatusChanged(Akregator::StatusSearchLine::Status /*status*/)
+void SearchBar::slotStatusChanged(Akregator::StatusSearchButtons::Status /*status*/)
 {
     triggerTimer();
 }
@@ -109,7 +115,7 @@ std::vector<QSharedPointer<const AbstractMatcher>> SearchBar::matchers() const
 
 void SearchBar::updateQuickSearchLineText(const QString &searchLineShortcut)
 {
-    m_searchLine->setPlaceholderText(i18n("Search articles...<%1>", searchLineShortcut));
+    m_searchLine->setPlaceholderText(i18nc("@info:placeholder", "Search articles…<%1>", searchLineShortcut));
 }
 
 void SearchBar::slotSearchStringChanged(const QString &search)
@@ -121,7 +127,7 @@ void SearchBar::slotSearchStringChanged(const QString &search)
 void SearchBar::slotStopActiveSearch()
 {
     std::vector<QSharedPointer<const AbstractMatcher>> matchers;
-    Settings::setStatusFilter(m_searchLine->status());
+    Settings::setStatusFilter(m_statusSearchButtons->status());
     Settings::setTextFilter(m_searchText);
     m_matchers = matchers;
     Q_EMIT signalSearch(matchers);
@@ -143,27 +149,27 @@ void SearchBar::slotActivateSearch()
         textCriteria << authCrit;
     }
 
-    switch (m_searchLine->status()) {
-    case StatusSearchLine::AllArticles:
+    switch (m_statusSearchButtons->status()) {
+    case StatusSearchButtons::AllArticles:
         break;
-    case StatusSearchLine::NewArticles: {
+    case StatusSearchButtons::NewArticles: {
         Criterion crit(Criterion::Status, Criterion::Equals, New);
         statusCriteria << crit;
         break;
     }
-    case StatusSearchLine::UnreadArticles: {
+    case StatusSearchButtons::UnreadArticles: {
         Criterion crit1(Criterion::Status, Criterion::Equals, New);
         Criterion crit2(Criterion::Status, Criterion::Equals, Unread);
         statusCriteria << crit1;
         statusCriteria << crit2;
         break;
     }
-    case StatusSearchLine::ReadArticles: {
+    case StatusSearchButtons::ReadArticles: {
         Criterion crit(Criterion::Status, Criterion::Equals, Read);
         statusCriteria << crit;
         break;
     }
-    case StatusSearchLine::ImportantArticles: {
+    case StatusSearchButtons::ImportantArticles: {
         Criterion crit(Criterion::KeepFlag, Criterion::Equals, true);
         statusCriteria << crit;
         break;
@@ -177,7 +183,7 @@ void SearchBar::slotActivateSearch()
     if (!statusCriteria.isEmpty()) {
         matchers.push_back(QSharedPointer<const AbstractMatcher>(new ArticleMatcher(statusCriteria, ArticleMatcher::LogicalOr)));
     }
-    Settings::setStatusFilter(m_searchLine->status());
+    Settings::setStatusFilter(m_statusSearchButtons->status());
     Settings::setTextFilter(m_searchText);
     m_matchers = matchers;
     Q_EMIT signalSearch(matchers);
